[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# FactSet People client library for Python

[![API Version](https://img.shields.io/badge/api-v1.3.0-blue)]()
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.FactSetPeople/1.0.15)](https://pypi.org/project/fds.sdk.FactSetPeople/v/1.0.15)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

The FactSet People API exposes FactSet data for individuals and their jobs.<p>This API is rate-limited to 10 requests per second and 10 concurrent requests per user.</p>


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.3.0
- SDK version: 1.0.15
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.FactSetPeople==1.0.15
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.FactSetPeople==1.0.15
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.FactSetPeople
from fds.sdk.FactSetPeople.api import company_api
from fds.sdk.FactSetPeople.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.FactSetPeople.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.FactSetPeople.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.FactSetPeople.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = company_api.CompanyApi(api_client)
    ids = ["AAPL-US","IBM-US"] # [str] | The requested company identifier. FactSet Identifiers, tickers, CUSIP, SEDOL, and ISIN are accepted inputs. <p>***ids limit** =  1000 per request*</p> *<p>Make note, GET Method URL request lines are also limited to a total length of 8192 bytes (8KB). In cases where the service allows for thousands of ids, which may lead to exceeding this request line limit of 8KB, its advised for any requests with large request lines to be requested through the respective \"POST\" method.</p>* 

    try:
        # Returns the compensation details of the people for the specified company identifier
        # example passing only required values which don't have defaults set
        api_response = api_instance.get_company_compensation(ids)

        pprint(api_response)
    except fds.sdk.FactSetPeople.ApiException as e:
        print("Exception when calling CompanyApi->get_company_compensation: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Returns the compensation details of the people for the specified company identifier
    #     api_response, http_status_code, response_headers = api_instance.get_company_compensation_with_http_info(ids)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.FactSetPeople.ApiException as e:
    #     print("Exception when calling CompanyApi->get_company_compensation: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Returns the compensation details of the people for the specified company identifier
    #     async_result = api_instance.get_company_compensation_async(ids)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.FactSetPeople.ApiException as e:
    #     print("Exception when calling CompanyApi->get_company_compensation: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Returns the compensation details of the people for the specified company identifier
    #     async_result = api_instance.get_company_compensation_with_http_info_async(ids)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.FactSetPeople.ApiException as e:
    #     print("Exception when calling CompanyApi->get_company_compensation: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.FactSetPeople

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.FactSetPeople.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.FactSetPeople

configuration = fds.sdk.FactSetPeople.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.FactSetPeople

configuration = fds.sdk.FactSetPeople.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.FactSetPeople

configuration = fds.sdk.FactSetPeople.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/content*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CompanyApi* | [**get_company_compensation**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyApi.md#get_company_compensation) | **GET** /factset-people/v1/company-compensation | Returns the compensation details of the people for the specified company identifier
*CompanyApi* | [**get_company_compensation_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyApi.md#get_company_compensation_for_list) | **POST** /factset-people/v1/company-compensation | Returns the compensation details for the people for the specified company identifier
*CompanyApi* | [**get_company_people**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyApi.md#get_company_people) | **GET** /factset-people/v1/company-people | Returns the list of people for the specified company identifiers
*CompanyApi* | [**get_company_people_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyApi.md#get_company_people_for_list) | **POST** /factset-people/v1/company-people | Returns the list of people associated for a large list of company identitifers
*CompanyApi* | [**get_company_positions**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyApi.md#get_company_positions) | **GET** /factset-people/v1/company-positions | Returns the list of people for the specified company identifiers and position
*CompanyApi* | [**get_company_positions_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyApi.md#get_company_positions_for_list) | **POST** /factset-people/v1/company-positions | Returns the list of people associated for a large list of company identitifers and position
*CompanyApi* | [**get_company_stats**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyApi.md#get_company_stats) | **GET** /factset-people/v1/company-stats | Returns statistics about top leadership of a company.
*CompanyApi* | [**get_company_stats_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyApi.md#get_company_stats_for_list) | **POST** /factset-people/v1/company-stats | Returns statistics about top leadership of a company.
*JobHistoryApi* | [**get_people_jobs**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/JobHistoryApi.md#get_people_jobs) | **GET** /factset-people/v1/jobs | Returns the Job history of the person.
*JobHistoryApi* | [**get_people_jobs_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/JobHistoryApi.md#get_people_jobs_for_list) | **POST** /factset-people/v1/jobs | Returns the Job history for the large list of people.
*ProfilesApi* | [**get_people_profiles**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/ProfilesApi.md#get_people_profiles) | **GET** /factset-people/v1/profiles | Return information about the person with the specified entity ID.
*ProfilesApi* | [**get_people_profiles_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/ProfilesApi.md#get_people_profiles_for_list) | **POST** /factset-people/v1/profiles | Returns profile information for a large list of people.


## Documentation For Models

 - [CompanyCompensation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyCompensation.md)
 - [CompanyCompensationRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyCompensationRequest.md)
 - [CompanyCompensationResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyCompensationResponse.md)
 - [CompanyIds](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyIds.md)
 - [CompanyPeople](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyPeople.md)
 - [CompanyPeopleRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyPeopleRequest.md)
 - [CompanyPeopleResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyPeopleResponse.md)
 - [CompanyPositions](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyPositions.md)
 - [CompanyPositionsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyPositionsRequest.md)
 - [CompanyPositionsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyPositionsResponse.md)
 - [CompanyStats](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyStats.md)
 - [CompanyStatsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyStatsRequest.md)
 - [CompanyStatsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/CompanyStatsResponse.md)
 - [ErrorResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/ErrorResponse.md)
 - [ErrorResponseSubErrors](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/ErrorResponseSubErrors.md)
 - [Function](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/Function.md)
 - [Ids](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/Ids.md)
 - [Job](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/Job.md)
 - [Level](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/Level.md)
 - [MbType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/MbType.md)
 - [PeopleJobsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/PeopleJobsRequest.md)
 - [PeopleJobsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/PeopleJobsResponse.md)
 - [PeopleProfilesRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/PeopleProfilesRequest.md)
 - [PeopleProfilesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/PeopleProfilesResponse.md)
 - [Position](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/Position.md)
 - [Profile](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/Profile.md)
 - [Status](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/Status.md)
 - [Type](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPeople/v1/docs/Type.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.FactSetPeople.apis and fds.sdk.FactSetPeople.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.FactSetPeople.api.default_api import DefaultApi`
- `from fds.sdk.FactSetPeople.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.FactSetPeople
from fds.sdk.FactSetPeople.apis import *
from fds.sdk.FactSetPeople.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

